==> qtjambi-serialbus-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiSerialBus/QModbusDevice_shell.h <==
#ifndef QMODBUSDEVICE_SHELL_H
#define QMODBUSDEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSerialBus/qmodbusdevice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QModbusDevice_shell : public QModbusDevice, public QtJambiShellInterface
{
public:
    QModbusDevice_shell(QObject* parent0 = nullptr);
    ~QModbusDevice_shell() override;

    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool open() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QModbusDevice_access : public QModbusDevice
{
    void __qt_setError_cref_QString_QModbusDevice_Error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring errorText0, jint error1);
    void __qt_setState_QModbusDevice_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint newState0);
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_open(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QMODBUSDEVICE_SHELL_H

==> qtjambi-serialbus-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiSerialBus/QModbusDevice_shell.h <==
#ifndef QMODBUSDEVICE_SHELL_H
#define QMODBUSDEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSerialBus/qmodbusdevice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QModbusDevice_shell : public QModbusDevice, public QtJambiShellInterface
{
public:
    QModbusDevice_shell(QObject* parent0 = nullptr);
    ~QModbusDevice_shell() override;

    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool open() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QModbusDevice_access : public QModbusDevice
{
    void __qt_setError_cref_QString_QModbusDevice_Error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring errorText0, jint error1);
    void __qt_setState_QModbusDevice_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint newState0);
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_open(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QMODBUSDEVICE_SHELL_H
